# fichier bash à sourcer
# lecture et ecriture des parametres de config sambaedu4
# fichier à inclure au début de tout script devant accéder à la conf 
#
# assignation des variables de conf
usage() {
	echo "script permettant la lecture et ecriture des parametres de config sambaedu4" 
	echo "usage: $0 -h -v "
	echo "       -h :  show this help"
	echo "       -v :  mode verbeux : liste les variables initialisees"
	exit $1
}

get_config() {
	for conf in $(find /etc/sambaedu/sambaedu.conf* -name "*.conf" -type f); do
    	IFS='
'
		for ligne in $(sed -E "/^#.*$/d;s|^(\S+)\s*=\s*\"(.*)\"$|config_\1='\2'|g" $conf); do
        	eval $ligne
        done
    	IFS=
	done
}

# fonction permettant l'écriture des parametres
# set_config module param [value]
# verrouille le fichier durant tout le processus
set_config() {
    if [ "$1" == "sambaedu" ]; then
	    conf="/etc/sambaedu/sambaedu.conf"
    else
	    conf="/etc/sambaedu/sambaedu.conf.d/$1.conf"
    fi
    if [ -n "$2" ]; then
        ( flock -x 0  # on pose un verrou exclusif : si le ficiher est déjà verrouillé on attend
        if [ -f "$conf" ]; then
            if $(grep -q "^$2[= ]" $conf); then
               if [ -z "$3" ]; then
                   sed -i "/^${2}\s*=.*$/d" $conf
	       else
                   sed -i "s|^${2}\s*=\s*.*$|${2} = \"${3}\"|" $conf
               fi
            elif [ -n "$3" ]; then
               echo "$2 = \"$3\"">>$conf
            fi
        else
	    if [ -n "$3" ]; then
                echo "$2 = \"$3\"">>$conf
            fi
        fi
        ) 0>/var/lock/sambaedu.lock
        chown www-admin /var/lock/sambaedu.lock >/dev/null 2>&1 || true
        eval config_$2=\'$3\'
    fi
}

# fonction permettant le renommage d'un parametre
# mv_config module old_param new_param [value]
# si pas de valeur on garde l'existante.
mv_config() {
    if [ -n "$4" ]; then
        set_config $1 $3 "$4"
    else
        param=config_$2         
        set_config $1 $3 "${!param}"
    fi
    set_config $1 $2
}

# fonction pour écrire un parametre dans un fichier de conf
# usage : write_param fichier config_param
# remplace ###_PARAM_### par la valeur de $config_param dans le fichier
write_param() {
    param=${2/config_/}
    param=${param^^}
    valeur=$2
    sed -i "s|###_${param}_###|${!valeur}|g" $1
}

# fonction pour mettre à jour un fichier de conf :
# usage : update_conf fichier field param
# field[ ]= valeur : remplace valeur par $config_param

update_conf() {
    conf=$1
    field=$2
    param=$3
    ( flock -x 0
    if [ -n "$field" ]; then
    	re=".*$field[= ]*"
        if grep -q "$re" $conf; then
            sed -i "s|^\(\s*${field}[\s=]*\).*$|\1 $param|" $conf
        else
            echo "$field = $param">>$conf
        fi
	fi
	) 0>/var/lock/sambaedu.lock
}

display_conf() {
    
    if [ -z "$1" ]; then
        opt="all"
    else
        opt="$1"
    fi
    case $opt in	
	all)
	
	confs="$(find /etc/sambaedu/sambaedu.conf* -name "*.conf" -type f| tr "\n" " ")"
        ;;
	
	sambaedu)
	confs="/etc/sambaedu/sambaedu.conf"
        ;;
	
	ent) 
	confs="/etc/sambaedu/sambaedu.conf.d/ent.conf"
        ;;
	
	dhcp)
	confs="/etc/sambaedu/sambaedu.conf.d/dhcp.conf"
	;;
	
	radius)
	confs="/etc/sambaedu/sambaedu.conf.d/sambaedu-radius.conf"
	;;
	
	gpo)
	confs="/etc/sambaedu/sambaedu.conf.d/gpo.conf"
	;;
	
	clients)
	confs="/etc/sambaedu/sambaedu.conf.d/clients.conf"
	;;
	
	wpkg)
	confs="/etc/sambaedu/sambaedu.conf.d/wpkg.conf"
	;;
    esac
    old_ifs="$IFS"
    IFS=' ' 
    for conf in $confs
    do
    
        echo "-------------------------------------------------------------"
        echo "Fichier de config $conf"
        echo "-------------------------------------------------------------"
        sed -E "/^#.*$/d;s|^(\S+)\s*=\s*\"(.*)\"$|config_\1='\2'|g" $conf
        echo ""
    done
    IFS="$old_ifs"
}

# lecture de la conf
get_config 
