# fichier bash à sourcer
# incompatible sh /dash !!!
# fonctions utiles pour générer les configurations des services sambaedu
# 
# Denis Bonnenfant
#
# licence GPL

cdr2mask()
{
   # Number of args to shift, 255..255, first non-255 byte, zeroes
   set -- $(( 5 - ($1 / 8) )) 255 255 255 255 $(( (255 << (8 - ($1 % 8))) & 255 )) 0 0 0
   [ $1 -gt 1 ] && shift $1 || shift
   echo ${1-0}.${2-0}.${3-0}.${4-0}
}

# Fonction permettant de récuperer la configuration réseau complète
# 
# 

my_network() {

IFS=" "
read my_gateway my_interface<<<$(ip -o -f inet route show default 0.0.0.0/0 | cut -d ' ' -f3,5)
read my_address my_cdr my_broadcast<<<$(ip -o -f inet addr show dev "$my_interface" | awk '{sub("/", " ", $4); print $4, $6}')
my_mask=$(cdr2mask $my_cdr)
IFS=
my_network=$(ip -o -f inet route show dev $my_interface  src $my_address | cut -d/ -f1)
my_hostname=$(hostname -s 2>/dev/null)
#my_domain=$(hostname -d 2>/dev/null) || true
my_fqdn=$(hostname -f 2>/dev/null) || true
# attention ne donne pas le dns externe si ad est configuré
my_dnsserver=$(grep -m 1 "^nameserver" /etc/resolv.conf | cut -d" " -f2) || true
my_domain=$(grep -m 1 -e "^domain\s*.*$" -o -e "^search\s*.*$" /etc/resolv.conf | cut -d" " -f2) || true
my_proxy="$http_proxy"
read my_proxy_address my_proxy_port<<<$(echo $my_proxy | sed "s!http://!!" | cut -d ':' -f1,2)

if [ -e "etc/sambaedu/sambaedu.conf.d/dhcp.conf" ]; then
    my_vlan=$(grep $my_network /etc/sambaedu/sambaedu.conf.d/dhcp.conf | cut -d= -f1 | sed "s/^.*_//")
fi
filtre="^\s*iface\s*${my_interface}\s*inet.*$"
my_mode=$(grep -e "$filtre" /etc/network/interfaces | cut -d" " -f4)
}

function check_proxy_params() {
if [ -n "$config_proxy_address" ] && [ -z "$config_proxy_port" ];then
    echo "Paramètres incorrect"
    exit 1
fi
}

function clean_old_proxy_params() {

profile_file="/etc/profile"
wgetrc_file="/etc/wgetrc"

sed -i '/http_proxy=/d' $profile_file
sed -i '/https_proxy=/d' $profile_file
sed -i '/ftp_proxy=/d' $profile_file
sed -i '/^export http_proxy/d' $profile_file
sed -i '/^http_proxy/d' $wgetrc_file
sed -i '/^https_proxy/d' $wgetrc_file
sed -i '/^use_proxy = on/d' $wgetrc_file

}

function set_proxy_params() {

profile_file="/etc/profile"
wgetrc_file="/etc/wgetrc"

echo "http_proxy=\"http://$1\"" >> $profile_file
echo "https_proxy=\"http://$1\"" >> $profile_file
echo "ftp_proxy=\"http://$1\"" >> $profile_file
echo "export http_proxy https_proxy ftp_proxy" >> $profile_file
echo "http_proxy = http://$1" >> $wgetrc_file
echo "https_proxy = http://$1" >> $wgetrc_file
echo "use_proxy = on" >> $wgetrc_file
}

#Activation Debug
function debug() {
debug="1"
if [ "$debug" = "1" ]; then
set -x
poursuivre
fi
}

# Affichage de la partie actuelle
function show_part()
{
echo -e "$COLPARTIE"
echo -e "--------"
echo "$1"
echo -e "-------- $COLTXT"
# sleep 1
}

# Affichage d'une info
function show_info()
{
echo -e "$COLINFO"
echo -e "$1 $COLTXT"
# sleep 1
}

function show_progress()
{
[ $cpt -eq 1 ] && echo "Traitement de $cpt_fin éléments lancé..."
echo "$cpt" | grep -q "0$" && echo -e "$cpt..\c"
[ $cpt -eq $cpt_fin ] && echo "Terminé !"
let cpt++
}

function check_winbind()
{
show_info "Vérification de Winbind"
if systemctl status winbind.service | grep -q "running"
then
   echo "Winbind est bien actif"
else
   echo "Winbind n'est pas actif ou est en défaut - abandon !"
   echo "Vous pouvez tenter de le relancer par systemctl restart winbind"
   
   exit 1
fi
}

function correct_home()
{
show_part "Remise en place des droits sur /home"
check_winbind
liste_users="$(wbinfo -u)"
cpt=1
cpt_fin="$(ls /home | wc -l)"
ls /home | while read useruid
do
    show_progress
    if [ "$useruid" != "templates" -a "$useruid" != "profiles" ]; then
        if echo "$liste_users" | grep -q "$useruid"
        then
            # pas d'acls sur le dossier 
            setfacl -b -R /home/$useruid
            
            # remise en place des droits
            chmod -R 770 /home/$useruid
            chown -R $useruid:Domain\ admins /home/$useruid
            # prop=`stat -c%G /home/$useruid`
        else
            show_info "$useruid ne semble pas faire partie des utilisateurs /home/$useruid sera ignoré"
        fi
    fi
done
chmod 777 /home/profiles
chgrp domain\ users /home/profiles
}
